<cfscript>

   // This file is provided under the terms of the BrowserHawk4J license
   // agreement.  Copyright (c) 2005 cyScape, Inc. All rights reserved.

   // One of the most challenging aspects of deploying Java applets is
   // guaranteeing that your visitor's browser has Java installed, enabled,
   // and of a particular version and vendor that are known to work with
   // your applet. BrowserHawk makes this process easy by enabling you to
   // detect, before sending your applet to the client, what the client's
   // capabilities and settings are. 

   // Unfortunately Java detection isn't as easy as a simple on/off switch
   // because of the various settings and variables involved. This sample
   // therefore is designed to walk you through the process and explain how
   // to make the most of BrowserHawk when detecting your visitor's Java
   // capabilities within their browser.

   // This sample tests the various properties involved in sniffing Java,
   // and based on the returned values, reports the client's Java
   // capabilities. You should feel free to use this sample as the basis for
   // how you sniff Java in your own application.


   // Get the BrowserHawk object
   bh = CreateObject("java", "com.cyscape.browserhawk.BrowserHawk");

   // BrowserHawk4J extended property detection is configured w/ ExtendedOptions
   options = CreateObject("java", "com.cyscape.browserhawk.ExtendedOptions");

   // Set the properties to test to be Flash presence and the Flash version
   ebi = CreateObject("java", "com.cyscape.browserhawk.ExtendedBrowserInfo");
   options.addProperties("JavaScriptEnabled,JavaEnabled,Plugin_JavaVer,JavaVersion,JavaVendor,MSJVMBuild");

  options.setPageMessage("Please wait while we check your Java for compatibility...");
  options.setPageTitle("Please wait...");

  // Get the HttpServletRequest and HttpServletResponse
  req = getPageContext().getRequest(); 
  res = getPageContext().getResponse(); 
 
  // Run the extended property detection.
  // If ebi is null that means the JavaScript has been sent and we should
  // return immediately and wait for the client's next request with answers.
  ebi = bh.getExtendedBrowserInfo(req, res, options);

  // Get the basic browser properties (sets basic properties like browser name, type, version)
  bi = bh.getBrowserInfo(req);

  </cfscript>

  <!---
   If ebi is empty, we must end the current request here.  The browser will
   now process the client side tests and call this page back a second time,
   this time with the answers.  On this second trip, ebi will not be "" and
   the code will continue below instead of ending here like it did the first
   time.
  --->

  <cfif NOT IsDefined("ebi")>
    <cfabort>
  </cfif>



<html>
<head><title>BrowserHawk Java Test Page</title></head>

<body bgcolor=white>
<font face="helvetica">

<h2>BrowserHawk Java Test Page</h2>

Java test results as detected by 
<a href="http://www.cyscape.com">BrowserHawk</a>:<br>

<!---
 The returned value is the UNSUPPORTED constant if the browser isn't
 Netscape, Mozilla, Firefox, IE, Opera, Safari, or AOL Explorer.
--->

 <cfif ebi EQ ebi.UNSUPPORTED>
    <big>No extended information is available.  Only Netscape,
    Mozilla, Firefox, IE, Opera, Safari, and AOL Explorer browsers are supported.</big>

 <cfelseif ebi.getJavaScriptEnabled() EQ False>
  <big>No Java detection information is available.  This client has
  JavaScript disabled.</big>

 <cfelseif isSupportedBrowser(bi) EQ False>
  <big>No Java detection is available.<br>For Java detection your browser has
  to be IE Windows 3+ (except exactly 4.00), Mozilla, Firefox, Safari 1.2+,
  Netscape 4.0+, Opera 7+, or AOLBrowser.</big>

 <cfelse>

    <br>

    <table>
    <tr><th align="left">Property</th><th>Value</th></tr>

    <tr><td width="150">JavaEnabled</font></td>
    <td>
        <cfoutput>#ebi.getJavaEnabled()#</cfoutput>
    </td></tr>

    <tr><td width="150">Plugin_JavaVer</font></td>
    <td>
       <cfoutput>#ebi.getPluginJavaVer()#</cfoutput>
    </td></tr>

    <tr><td width="150">JavaVersion</font></td>
    <td>
       <cfoutput>#ebi.getJavaVersion()#</cfoutput>
    </td></tr>
    
    <tr><td width="150">JavaVendor</font></td>
    <td>
       <cfoutput>#ebi.getJavaVendor()#</cfoutput>
    </td></tr>

    <tr><td width="150">MSJVMBuild</font></td>
    <td>
       <cfoutput>#ebi.getMSJVMBuild()#</cfoutput>
    </td></tr>

    </table>

    <br>
    <b>Conclusion:</b>
    <p>

    <cfscript>
       javaVendor = ebi.getJavaVendor();
       javaVersion = ebi.getJavaVersion();
       pluginJavaVer = ebi.getPluginJavaVer();
       msjvmBuild = ebi.getMSJVMBuild();

     </cfscript>

     <!--- Define a warning message in case its needed --->
     <cfset developerWarning =  "<p>(Note for the developer: It's also possible that this condition is occurring because the JVMDetector.class file is not being found. This .class file is distributed with the BrowserHawk files and should be placed into the same directory where your web script is running. Or, you can place it into another web directory and use BrowserHawk's ExtendedOptions.setJVMCodeBase() to tell BrowserHawk what the path to the web directory should be for applet downloads. The web server's access logs can reveal if the class file is being found and downloaded or not.)">

     <cfif NOT IsDefined("pluginJavaVer")>
        <cfset pluginJavaVer = "">
     </cfif>
     <cfif IsDefined("msjvmbuild") EQ False>
        <cfset msjvmbuild = "">
     </cfif>

     <!--- Java disabled and non-empty version is a strong indication Java's disabled --->
     <cfif ebi.getJavaEnabled() EQ False AND pluginJavaVer NEQ "">
        JavaEnabled returned false while Plugin_JavaVer detection returned a legitimate
        value.<br>This indicates you have the Java Plugin <%= pluginJavaVer %> installed
        but it's currently disabled.

     <cfelseif ebi.getJavaEnabled() EQ False AND msjvmbuild NEQ "">
        JavaEnabled returned false while MSJVMBuild detection returned a legitimate
        value.<br>This indicates you have the the MSJVM Build <%= msjvmBuild %> installed
        but it's currently disabled.

     <cfelseif ebi.getJavaVersion() EQ "-3">
        JavaVersion returned -3. This indicates you have no Java installed.

     <cfelseif ebi.getJavaEnabled() EQ False> <!--- implicitly pluginJavaVer and msjvmBuild are null --->
        JavaEnabled returned false and Plugin_JavaVer/MSJVMBuild detection returned no legitimate
        value.<br>This indicates you probably have no Java installed.

     <cfelseif javaVersion EQ "-1">
        JavaEnabled returned true while JavaVersion returned -1.<br>This indicates you
        most likely have a very old JVM which can't be accessed from JavaScript.
        <cfoutput>#developerWarning#</cfoutput>

     <cfelseif javaVersion EQ "-2" AND pluginJavaVer NEQ "">
        JavaEnabled returned true, JavaVersion returned -2, and Plugin_JavaVer
        detection returned a legitimate value.<br>This indicates you have the Java Plugin
        <cfoutput>#pluginJavaVer#</cfoutput> installed but scripting of applets is explicitly disabled
        so it's not possible to confirm the behavior of an applet.
        <cfoutput>#developerWarning#</cfoutput>

     <cfelseif javaVersion EQ "-2" AND msjvmbuild NEQ "">
        JavaEnabled returned true, JavaVersion returned -2, and MSJVMBuild
        detection returned a legitimate value.<br>This indicates you have the MSJVM Build
        <cfoutput>#msjvmBuild#</cfoutput> installed but scripting of applets is explicitly disabled
        so it's not possible to confirm the behavior of an applet.
        <cfoutput>#developerWarning#</cfoutput>

     <cfelseif javaVersion EQ "-2"> <!--- implicitly pluginJavaVer and msjvmBuild are null --->
        JavaEnabled returned true, JavaVersion returned -2, and Plugin_JavaVer/MSJVMBuild
        detection returned no legitimate value.<br>This indicates you don't have any
        Java installed.
        <cfoutput>#developerWarning#</cfoutput>

     <cfelseif IsDefined("javaVersion") AND javaVersion NEQ ""> <!--- javaVendor exists if javaVersion exists --->
         JavaVersion and JavaVendor indicate you have Java <cfoutput>#javaVersion#</cfoutput> from <cfoutput>#javaVendor#</cfoutput>
         ready to run applets under <cfoutput>#bi.getBrowser()#</cfoutput> <cfoutput>#bi.getVersion()#</cfoutput>
         on <cfoutput>#bi.getPlatform()#</cfoutput>.

         <!--- If the first 3 chars don't match between javaVersion and pluginJavaVer,
               add a note about what plugin might be available. --->
         <cfif Left(javaVersion, 3) NEQ Left(pluginJavaVer, 3) AND pluginJavaVer NEQ "">
            <cfoutput>You also have the Java Plugin version #pluginJavaVer# at your disposal.</cfoutput>
         </cfif>
     </cfif>
</cfif>

<p>
<hr>
<P>
<b><a href="java.cfm">Retry this test</a></b><P>
<b><a href="index.html">Return to list of other CFMX samples</a></b><P>
<b><a href="http://www.cyscape.com/order/">BrowserHawk Pricing and Ordering</a></b><P>
<b><a href="http://www.cyscape.com/">cyScape home page</a></b><P>
</font></blockquote>
</body>
</html>



<cffunction name="isSupportedBrowser">
  <cfargument name="bi">

    <cfscript>
       browser = bi.getBrowser();
       version = bi.getVersion();
       platform = bi.getPlatform();
    </cfscript>

    <cfif browser EQ "Mozilla" OR browser EQ "Firefox"> 
        <cfreturn True>
    </cfif>

    <cfif browser EQ "Safari" AND version GTE 1.2> 
        <cfreturn True>
    </cfif>

    <cfif browser EQ "Netscape" AND version GTE 4.0> 
        <cfreturn True>
    </cfif>

    <cfif browser EQ "Opera" AND version GTE 7.0> 
        <cfreturn True>
    </cfif>

    <cfif browser EQ "IE" AND version GTE 3.0 AND version NEQ 4.0 AND Left(platform,3) EQ "Win"> 
        <cfreturn True>
    </cfif>

    <cfreturn False>

</cffunction>

